@@ -1,11 +1,11 @@
-/* audispd-pconfig.c -- 
- * Copyright 2007,2010,2015 Red Hat Inc., Durham, North Carolina.
+/* audispd-pconfig.c --
+ * Copyright 2007,2010,2015,2021-23 Red Hat Inc.
  * All Rights Reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This software may be freely redistributed and/or modified under the
+ * terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2, or (at your option) any
+ * later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,12 +13,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; see the file COPYING. If not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor
+ * Boston, MA 02110-1335, USA.
  *
  * Authors:
  *   Steve Grubb <sgrubb@redhat.com>
- * 
+ *
  */
 
 #include "config.h"
@@ -41,7 +42,7 @@ struct nv_pair
 	const char *option;
 };
 
-struct kw_pair 
+struct kw_pair
 {
 	const char *name;
 	int (*parser)(struct nv_pair *, int, plugin_conf_t *);
@@ -49,7 +50,7 @@ struct kw_pair
 };
 
 struct nv_list
-{ 
+{
 	const char *name;
 	int option;
 };
@@ -162,25 +163,25 @@ int load_pconfig(plugin_conf_t *config, char *file)
 	 * not symlink.
 	 */
 	if (fstat(fd, &st) < 0) {
-		audit_msg(LOG_ERR, "Error fstat'ing config file (%s)", 
+		audit_msg(LOG_ERR, "Error fstat'ing config file (%s)",
 			strerror(errno));
 		close(fd);
 		return 1;
 	}
 	if (st.st_uid != 0) {
-		audit_msg(LOG_ERR, "Error - %s isn't owned by root", 
+		audit_msg(LOG_ERR, "Error - %s isn't owned by root",
 			file);
 		close(fd);
 		return 1;
 	}
 	if ((st.st_mode & S_IWOTH) == S_IWOTH) {
-		audit_msg(LOG_ERR, "Error - %s is world writable", 
+		audit_msg(LOG_ERR, "Error - %s is world writable",
 			file);
 		close(fd);
 		return 1;
 	}
 	if (!S_ISREG(st.st_mode)) {
-		audit_msg(LOG_ERR, "Error - %s is not a regular file", 
+		audit_msg(LOG_ERR, "Error - %s is not a regular file",
 			file);
 		close(fd);
 		return 1;
@@ -189,7 +190,7 @@ int load_pconfig(plugin_conf_t *config, char *file)
 	/* it's ok, read line by line */
 	f = fdopen(fd, "rm");
 	if (f == NULL) {
-		audit_msg(LOG_ERR, "Error - fdopen failed (%s)", 
+		audit_msg(LOG_ERR, "Error - fdopen failed (%s)",
 			strerror(errno));
 		close(fd);
 		return 1;
@@ -204,18 +205,18 @@ int load_pconfig(plugin_conf_t *config, char *file)
 			case 0: // fine
 				break;
 			case 1: // not the right number of tokens.
-				audit_msg(LOG_ERR, 
-				"Wrong number of arguments for line %d in %s", 
+				audit_msg(LOG_ERR,
+				"Wrong number of arguments for line %d in %s",
 					lineno, file);
 				break;
 			case 2: // no '=' sign
-				audit_msg(LOG_ERR, 
-					"Missing equal sign for line %d in %s", 
+				audit_msg(LOG_ERR,
+					"Missing equal sign for line %d in %s",
 					lineno, file);
 				break;
-			default: // something else went wrong... 
-				audit_msg(LOG_ERR, 
-					"Unknown error for line %d in %s", 
+			default: // something else went wrong...
+				audit_msg(LOG_ERR,
+					"Unknown error for line %d in %s",
 					lineno, file);
 				break;
 		}
@@ -231,8 +232,8 @@ int load_pconfig(plugin_conf_t *config, char *file)
 		/* identify keyword or error */
 		kw = kw_lookup(nv.name);
 		if (kw->name == NULL) {
-			audit_msg(LOG_ERR, 
-				"Unknown keyword \"%s\" in line %d of %s", 
+			audit_msg(LOG_ERR,
+				"Unknown keyword \"%s\" in line %d of %s",
 				nv.name, lineno, file);
 			fclose(f);
 			return 1;
@@ -240,9 +241,9 @@ int load_pconfig(plugin_conf_t *config, char *file)
 
 		/* Check number of options */
 		if (kw->max_options == 0 && nv.option != NULL) {
-			audit_msg(LOG_ERR, 
+			audit_msg(LOG_ERR,
 				"Keyword \"%s\" has invalid option "
-				"\"%s\" in line %d of %s", 
+				"\"%s\" in line %d of %s",
 				nv.name, nv.option, lineno, file);
 			fclose(f);
 			return 1;
@@ -347,8 +348,8 @@ static const struct kw_pair *kw_lookup(const char *val)
 	}
 	return &keywords[i];
 }
- 
-static int active_parser(struct nv_pair *nv, int line, 
+
+static int active_parser(struct nv_pair *nv, int line,
 		plugin_conf_t *config)
 {
 	int i;
@@ -363,7 +364,7 @@ static int active_parser(struct nv_pair *nv, int line,
 	return 1;
 }
 
-static int direction_parser(struct nv_pair *nv, int line, 
+static int direction_parser(struct nv_pair *nv, int line,
 		plugin_conf_t *config)
 {
 	int i;
@@ -378,11 +379,11 @@ static int direction_parser(struct nv_pair *nv, int line,
 	return 1;
 }
 
+static const char *BUILTIN_PATH="/sbin/audisp-af_unix";
 static int path_parser(struct nv_pair *nv, int line,
 	plugin_conf_t *config)
 {
 	char *dir = NULL, *tdir;
-	struct stat buf;
 
 	if (nv->value == NULL) {
 		config->path = NULL;
@@ -390,7 +391,10 @@ static int path_parser(struct nv_pair *nv, int line,
 	}
 
 	if (strncasecmp(nv->value, "builtin_", 8) == 0) {
-		config->path = strdup(nv->value);
+		audit_msg(LOG_WARNING,
+			  "Option %s line %d is obsolete - using %s",
+			  nv->value, line, BUILTIN_PATH);
+		config->path = strdup(BUILTIN_PATH);
 		return 0;
 	}
 
@@ -407,35 +411,14 @@ static int path_parser(struct nv_pair *nv, int line,
 	}
 
 	free((void *)tdir);
-	/* If the file exists, see that its regular, owned by root,
-	 * and not world anything */
-	if (stat(nv->value, &buf) < 0) {
-		audit_msg(LOG_ERR, "Unable to stat %s (%s)", nv->value,
-			strerror(errno));
-		return 1;
-	}
-	if (!S_ISREG(buf.st_mode)) {
-		audit_msg(LOG_ERR, "%s is not a regular file", nv->value);
-		return 1;
-	}
-	if (buf.st_uid != 0) {
-		audit_msg(LOG_ERR, "%s is not owned by root", nv->value);
-		return 1;
-	}
-	if ((buf.st_mode & (S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP)) !=
-			   (S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP)) {
-		audit_msg(LOG_ERR, "%s permissions should be 0750", nv->value);
-		return 1;
-	}
 	free((void *)config->path);
 	config->path = strdup(nv->value);
-	config->inode = buf.st_ino;
 	if (config->path == NULL)
 		return 1;
 	return 0;
 }
 
-static int service_type_parser(struct nv_pair *nv, int line, 
+static int service_type_parser(struct nv_pair *nv, int line,
 		plugin_conf_t *config)
 {
 	int i;
@@ -443,6 +426,11 @@ static int service_type_parser(struct nv_pair *nv, int line,
 	for (i=0; service_type[i].name != NULL; i++) {
 		if (strcasecmp(nv->value, service_type[i].name) == 0) {
 			config->type = service_type[i].option;
+			if (config->type == S_BUILTIN) {
+				audit_msg(LOG_WARNING,
+		"Option %s line %d is obsolete - update it", nv->value, line);
+				config->type = S_ALWAYS;
+			}
 			return 0;
 		}
 	}
@@ -466,7 +454,7 @@ static int args_parser(struct nv_pair *nv, int line,
 	return 0;
 }
 
-static int format_parser(struct nv_pair *nv, int line, 
+static int format_parser(struct nv_pair *nv, int line,
 		plugin_conf_t *config)
 {
 	int i;
@@ -489,11 +477,45 @@ static int format_parser(struct nv_pair *nv, int line,
 static int sanity_check(plugin_conf_t *config, const char *file)
 {
 	/* Error checking */
-	if (config->active == A_YES && config->path == NULL) {
-		audit_msg(LOG_ERR, 
+	if (config->active == A_YES) {
+		struct stat buf;
+
+		if (config->path == NULL) {
+			audit_msg(LOG_ERR,
 		    "Error - plugin (%s) is active but no path given", file);
-		return 1;
+			return 1;
+		}
+		// Don't check builtins
+		if (strncasecmp(config->path, "builtin_", 8) == 0)
+			goto out;
+
+		/* If the file exists, see that its regular, owned by root,
+		 * and not world anything */
+		if (stat(config->path, &buf) < 0) {
+			audit_msg(LOG_ERR, "Unable to stat %s (%s)",
+				  config->path,	strerror(errno));
+			return 1;
+		}
+		if (!S_ISREG(buf.st_mode)) {
+			audit_msg(LOG_ERR, "%s is not a regular file",
+				 config->path);
+			return 1;
+		}
+		if (buf.st_uid != 0) {
+			audit_msg(LOG_ERR, "%s is not owned by root",
+				 config->path);
+			return 1;
+		}
+		if ((buf.st_mode & (S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP)) !=
+				   (S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP)) {
+			audit_msg(LOG_ERR, "%s permissions should be 0750",
+				 config->path);
+			return 1;
+		}
+		// Passes, record inode
+		config->inode = buf.st_ino;
 	}
+out:
 	return 0;
 }
 
