@@ -1235,9 +1235,10 @@ static const char *print_sockaddr(const char *val)
         switch (saddr->sa_family) {
                 case AF_LOCAL:
 			if (slen < 4) {
-				rc = asprintf(&out,
-				    "{ saddr_fam=%s sockaddr len too short }",
-							str);
+				rc = asprintf(&out, "{ saddr_fam=%s %s }", str,
+				    slen == sizeof(saddr->sa_family) ?
+				    "unnamed socket" : // ignore sun_path
+				    "sockaddr len too short");
 				break;
 			} else {
                                 const struct sockaddr_un *un =
@@ -2432,6 +2433,29 @@ static const char *print_fan_info(const char *val)
 	return out;
 }
 
+/* This is in IMA audit events */
+static const char *print_errno(const char *val)
+{
+	char *out;
+	const char *err_name;
+	int err;
+
+	errno = 0;
+	err = strtoul(val, NULL, 10);
+	if (errno) {
+		if (asprintf(&out, "conversion error(%s)", val) < 0)
+			out = NULL;
+		return out;
+	}
+	err_name = audit_errno_to_name(err);
+	if (err_name == NULL)
+		out = strdup("UNKNOWN");
+	else
+		out = strdup(err_name);
+
+	return out;
+}
+
 static const char *print_a0(const char *val, const idata *id)
 {
 	char *out;
@@ -3355,6 +3379,9 @@ unknown:
 		case AUPARSE_TYPE_FAN_INFO:
 			out = print_fan_info(id->val);
 			break;
+		case AUPARSE_TYPE_ERRNO:
+			out = print_errno(id->val);
+			break;
 		case AUPARSE_TYPE_MAC_LABEL:
 		case AUPARSE_TYPE_UNCLASSIFIED:
 		default:
