@@ -17,6 +17,8 @@ static const char *buf[] = {
 		NULL
 };
 
+unsigned int walked_fields = 0;
+#define FIELDS_EXPECTED 403
 
 static void walk_test(auparse_state_t *au)
 {
@@ -28,16 +30,16 @@ static void walk_test(auparse_state_t *au)
 						strerror(errno));
 			exit(1);
 		}
-		printf("event %d has %d records\n", event_cnt,
+		printf("event %d has %u records\n", event_cnt,
 						auparse_get_num_records(au));
 		record_cnt = 1;
 		do {
-			printf("    record %d of type %d(%s) has %d fields\n",
+			printf("    record %d of type %d(%s) has %u fields\n",
 				record_cnt, 
 				auparse_get_type(au),
 				audit_msg_type_to_name(auparse_get_type(au)),
 				auparse_get_num_fields(au));
-			printf("    line=%d file=%s\n",
+			printf("    line=%u file=%s\n",
 				auparse_get_line_number(au),
 				auparse_get_filename(au) ?
 					auparse_get_filename(au) : "None");
@@ -55,6 +57,7 @@ static void walk_test(auparse_state_t *au)
 						auparse_get_field_name(au),
 						auparse_get_field_str(au),
 						auparse_interpret_field(au));
+                walked_fields++;
 			} while (auparse_next_field(au) > 0);
 			printf("\n");
 			record_cnt++;
@@ -72,15 +75,15 @@ void light_test(auparse_state_t *au)
 			puts("Error getting first record");
 			exit(1);
 		}
-		printf("event has %d records\n", auparse_get_num_records(au));
+		printf("event has %u records\n", auparse_get_num_records(au));
 		record_cnt = 1;
 		do {
-			printf("    record %d of type %d(%s) has %d fields\n",
+			printf("    record %d of type %d(%s) has %u fields\n",
 				record_cnt, 
 				auparse_get_type(au),
 				audit_msg_type_to_name(auparse_get_type(au)),
 				auparse_get_num_fields(au));
-			printf("    line=%d file=%s\n",
+			printf("    line=%u file=%s\n",
 				auparse_get_line_number(au),
 				auparse_get_filename(au) ?
 					auparse_get_filename(au) : "None");
@@ -228,16 +231,16 @@ static void auparse_callback(auparse_state_t *au, auparse_cb_event_t cb_event_ty
 			printf("can't get first record\n");
 			return;
 		}
-		printf("event %d has %d records\n", *event_cnt,
+		printf("event %d has %u records\n", *event_cnt,
 					auparse_get_num_records(au));
 		record_cnt = 1;
 		do {
-			printf("    record %d of type %d(%s) has %d fields\n",
+			printf("    record %d of type %d(%s) has %u fields\n",
 				record_cnt, 
 				auparse_get_type(au),
 				audit_msg_type_to_name(auparse_get_type(au)),
 				auparse_get_num_fields(au));
-			printf("    line=%d file=%s\n",
+			printf("    line=%u file=%s\n",
 				auparse_get_line_number(au),
 				auparse_get_filename(au) ?
 					auparse_get_filename(au) : "None");
@@ -462,6 +465,23 @@ int main(void)
 	}
         printf("Test 10 Done\n\n");
 
+	printf("Starting Test 11, walk LONG event records from a file...\n");
+	au = auparse_init(AUSOURCE_FILE, "test4.log");
+	if (au == NULL) {
+		printf("Error - %s\n", strerror(errno));
+		return 1;
+	}
+
+	walked_fields = 0;
+	walk_test(au);
+	auparse_destroy(au);
+
+	if (walked_fields != FIELDS_EXPECTED) {
+		printf("Error: %i fields expected, but %i read!\n",
+			   FIELDS_EXPECTED, walked_fields);
+	}
+	printf("Test 11 Done\n\n");
+
 	puts("Finished non-admin tests\n");
 
 	return 0;
