@@ -1,5 +1,5 @@
 /* audit-fgets.h -- a replacement for glibc's fgets
- * Copyright 2018 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2018,2022 Red Hat Inc.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -25,11 +25,16 @@
 
 #include <sys/types.h>
 #include "dso.h"
+#ifndef __attr_access
+#  define __attr_access(x)
+#endif
 AUDIT_HIDDEN_START
 
+void audit_fgets_clear(void);
 int audit_fgets_eof(void);
 int audit_fgets_more(size_t blen);
-int audit_fgets(char *buf, size_t blen, int fd);
+int audit_fgets(char *buf, size_t blen, int fd)
+	__attr_access ((__write_only__, 1, 2));
 
 char *audit_strsplit_r(char *s, char **savedpp);
 char *audit_strsplit(char *s);
