@@ -1,5 +1,5 @@
 /* auditctl.c --
- * Copyright 2004-2017,202-3 Red Hat Inc.
+ * Copyright 2004-2017,20-23 Red Hat Inc.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -1329,16 +1329,6 @@ static int fileopt(const char *file)
 		close(tfd);
 		return 1;
 	}
-	if (st.st_uid != 0) {
-		audit_msg(LOG_ERR, "Error - %s isn't owned by root", file);
-		close(tfd);
-		return 1;
-	} 
-	if ((st.st_mode & S_IWOTH) == S_IWOTH) {
-		audit_msg(LOG_ERR, "Error - %s is world writable", file);
-		close(tfd);
-		return 1;
-	}
 	if (!S_ISREG(st.st_mode)) {
 		audit_msg(LOG_ERR, "Error - %s is not a regular file", file);
 		close(tfd);
@@ -1464,7 +1454,7 @@ int main(int argc, char *argv[])
 		set_aumessage_mode(MSG_SYSLOG, DBG_NO);
 		fd = audit_open();
 		if (is_ready() == 0)
-			return 0;
+			return 1;
 		else if (fileopt(argv[2])) {
 			free(rule_new);
 			return 1;
@@ -1490,10 +1480,20 @@ int main(int argc, char *argv[])
 		fd = audit_open();
 		if (is_ready() == 0) {
 			free(rule_new);
-			return 0;
+			return 1;
 		}
 	}
 	retval = handle_request(retval);
+	if (retval == -1) {
+		if (errno != ECONNREFUSED)
+			audit_msg(LOG_ERR,
+				"There was an error while processing parameters");
+		else {
+			audit_msg(LOG_ERR,
+				"The audit system is disabled");
+			return 0;
+		}
+	}
 	free(rule_new);
 	return retval;
 }
