@@ -1,24 +1,23 @@
-/* auditd-config.c -- 
+/* auditd-config.c --
  * Copyright 2004-2011,2013-14,2016,2018,2020-21 Red Hat Inc.
  * All Rights Reserved.
+
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  * Authors:
  *   Steve Grubb <sgrubb@redhat.com>
- *
  */
 
 #include "config.h"
@@ -1844,7 +1843,7 @@ static int plugin_dir_parser(struct nv_pair *nv, int line,
 		config->plugin_dir = malloc(len + 2);
 		if (config->plugin_dir) {
 			strcpy(config->plugin_dir, nv->value);
-			if (config->plugin_dir[len - 1] != '/')
+			if (len > 1 && config->plugin_dir[len - 1] != '/')
 				config->plugin_dir[len] = '/';
 			config->plugin_dir[len + 1] = 0;
 		}
