@@ -63,6 +63,7 @@ long long event_exit = 0;
 int event_exit_is_set = 0;
 int event_ppid = -1, event_session_id = -2;
 int event_debug = 0, event_machine = -1;
+time_t	arg_eoe_timeout = (time_t)0;
 
 /* These are used by aureport */
 const char *dummy = "dummy";
@@ -86,7 +87,7 @@ enum {  R_INFILE, R_TIME_END, R_TIME_START, R_VERSION, R_SUMMARY, R_LOG_TIMES,
 	R_INTERPRET, R_HELP, R_ANOMALY, R_RESPONSE, R_SUMMARY_DET, R_CRYPTO,
 	R_MAC, R_FAILED, R_SUCCESS, R_ADD, R_DEL, R_AUTH, R_NODE, R_IN_LOGS,
 	R_KEYS, R_TTY, R_NO_CONFIG, R_COMM, R_VIRT, R_INTEG, R_ESCAPE,
-	R_DEBUG };
+	R_DEBUG, R_EOE_TMO };
 
 static struct nv_pair optiontab[] = {
 	{ R_AUTH, "-au" },
@@ -104,6 +105,7 @@ static struct nv_pair optiontab[] = {
 	{ R_EVENTS, "-e" },
 	{ R_EVENTS, "--event" },
 	{ R_ESCAPE, "--escape" },
+	{ R_EOE_TMO, "--eoe-timeout" },
 	{ R_FILES, "-f" },
 	{ R_FILES, "--file" },
 	{ R_FAILED, "--failed" },
@@ -175,7 +177,10 @@ static void usage(void)
 	"\t--comm\t\t\t\tCommands run report\n"
 	"\t-c,--config\t\t\tConfig change report\n"
 	"\t-cr,--crypto\t\t\tCrypto report\n"
+	"\t--debug\t\t\t\tWrite malformed events that are skipped to stderr\n"
+	"\t--eoe-timeout secs\t\tEnd of Event Timeout\n"
 	"\t-e,--event\t\t\tEvent report\n"
+	"\t--escape option\t\t\tEscape output\n"
 	"\t-f,--file\t\t\tFile name report\n"
 	"\t--failed\t\t\tonly failed events in report\n"
 	"\t-h,--host\t\t\tRemote Host name report\n"
@@ -184,8 +189,8 @@ static void usage(void)
 	"\t-if,--input <Input File name>\tuse this file as input\n"
 	"\t--input-logs\t\t\tUse the logs even if stdin is a pipe\n"
 	"\t--integrity\t\t\tIntegrity event report\n"
-	"\t-l,--login\t\t\tLogin report\n"
 	"\t-k,--key\t\t\tKey report\n"
+	"\t-l,--login\t\t\tLogin report\n"
 	"\t-m,--mods\t\t\tModification to accounts report\n"
 	"\t-ma,--mac\t\t\tMandatory Access Control (MAC) report\n"
 	"\t-n,--anomaly\t\t\taNomaly report\n"
@@ -261,8 +266,8 @@ int check_params(int count, char *vars[])
 					vars[c]);
 				retval = -1;
 			} else {
-				if (strlen(optarg) >= PATH_MAX) {
-					fprintf(stderr, 
+				if (strlen(optarg) >= PATH_MAX-32) {
+					fprintf(stderr,
 						"File name is too long %s\n",
 						optarg);
 					retval = -1;
@@ -750,9 +755,31 @@ int check_params(int count, char *vars[])
 			usage();
 			exit(0);
 			break;
+		case R_EOE_TMO:
+			if (!optarg) {
+				fprintf(stderr,
+					"Argument is required for %s\n",
+					vars[c]);
+				retval = -1;
+				break;
+			}
+			if (isdigit(optarg[0])) {
+				errno = 0;
+				arg_eoe_timeout = (time_t)strtoul(optarg, NULL, 10);
+				if (errno || arg_eoe_timeout == 0) {
+					fprintf(stderr,
+						"Illegal value for End of Event Timeout, was %s\n", optarg);
+					retval = -1;
+				}
+				c++;
+			} else {
+				fprintf(stderr,
+					"End of Event Timeout must be a numeric value, was %s\n", optarg);
+				retval = -1;
+			}
+			break;
 		default:
-			fprintf(stderr, "%s is an unsupported option\n", 
-				vars[c]);
+			fprintf(stderr, "%s is an unsupported option\n", vars[c]);
 			retval = -1;
 			break;
 		}
