@@ -1,6 +1,6 @@
 /*
 * ausearch-llist.h - Header file for ausearch-llist.c
-* Copyright (c) 2005-2008, 2013-14,2016 Red Hat Inc., Durham, North Carolina.
+* Copyright (c) 2005-2008, 2013-14,2016 Red Hat Inc.
 * Copyright (c) 2011 IBM Corp.
 * All Rights Reserved.
 *
@@ -16,7 +16,8 @@
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING. If not, write to the
-* Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor 
+* Boston, MA 02110-1335, USA.
 *
 * Authors:
 *   Steve Grubb <sgrubb@redhat.com>
@@ -68,9 +69,9 @@ typedef struct
   char *acct;           // account used when uid is invalid
   char *uuid;           // virtual machine unique universal identifier
   char *vmname;         // virtual machine name
-  const char *tuid;	// interpretted uid
-  const char *teuid;	// interpretted euid
-  const char *tauid;	// interpretted auid
+  const char *tuid;	// interpreted uid
+  const char *teuid;	// interpreted euid
+  const char *tauid;	// interpreted auid
 } search_items;
 
 /* This is the node of the linked list. Any data elements that are per
@@ -78,7 +79,8 @@ typedef struct
 typedef struct _lnode{
   char *message;		// The whole unparsed message
   char *interp;			// Beginning of interpretations within message
-  unsigned int mlen;		// Length of the message
+  unsigned int mlen;		// Length of the message up to separator
+  unsigned int tlen;		// Total message size
   int type;			// message type (KERNEL, USER, LOGIN, etc)
   unsigned long long a0;	// argv 0
   unsigned long long a1;	// argv 1
@@ -95,7 +97,7 @@ typedef struct {
 
 			// Data we add as 1 per event
   event e;		// event - time & serial number
-  search_items s;	// items in master rec that are searchable
+  search_items s;	// items in the record that are searchable
   int fmt;		// The event's format (raw, enriched)
 } llist;
 
