@@ -1,6 +1,6 @@
 /*
 * ausearch-lookup.h - Header file for ausearch-lookup.c
-* Copyright (c) 2005-06,2014,2017 Red Hat Inc., Durham, North Carolina.
+* Copyright (c) 2005-06,2014,2017,2022 Red Hat Inc.
 * All Rights Reserved.
 *
 * This software may be freely redistributed and/or modified under the
@@ -15,7 +15,7 @@
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING. If not, write to the
-* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor 
+* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor
 * Boston, MA 02110-1335, USA.
 *
 * Authors:
@@ -34,13 +34,16 @@
 
 const char *aulookup_result(avc_t result);
 const char *aulookup_success(int s);
-const char *aulookup_syscall(llist *l, char *buf, size_t size);
-const char *aulookup_uid(uid_t uid, char *buf, size_t size);
+const char *aulookup_syscall(llist *l, char *buf, size_t size)
+	__attr_access ((__write_only__, 2, 3));
+const char *aulookup_uid(uid_t uid, char *buf, size_t size)
+	__attr_access ((__write_only__, 2, 3));
 void aulookup_destroy_uid_list(void);
 char *unescape(const char *buf);
 int is_hex_string(const char *str);
 void print_tty_data(const char *val);
-void safe_print_string_n(const char *s, unsigned int len, int ret);
+void safe_print_string_n(const char *s, unsigned int len, int ret)
+	__attr_access ((__read_only__, 1, 2));
 void safe_print_string(const char *s, int ret);
 
 #endif
