@@ -46,6 +46,7 @@ struct nv_pair {
 static struct nv_pair timetab[] = {
         { T_NOW, "now" },
         { T_RECENT, "recent" },
+	{ T_THIS_HOUR, "this-hour" },
 	{ T_BOOT, "boot" },
         { T_TODAY, "today" },
         { T_YESTERDAY, "yesterday" },
@@ -70,6 +71,13 @@ int lookup_time(const char *name)
 
 }
 
+/* static void print_time(struct tm *d)
+{
+	char outstr[200];
+	strftime(outstr, sizeof(outstr), "%c", d);
+	printf("%s\n", outstr);
+} */
+
 static void clear_tm(struct tm *t)
 {
         t->tm_sec = 0;         /* seconds */
@@ -78,6 +86,8 @@ static void clear_tm(struct tm *t)
         t->tm_mday = 0;        /* day of the month */
         t->tm_mon = 0;         /* month */
         t->tm_year = 0;        /* year */
+	t->tm_wday = 0;	       /* not used */
+	t->tm_yday = 0;        /* not used */
         t->tm_isdst = 0;       /* DST flag */
 }
 
@@ -117,6 +127,15 @@ static void set_tm_recent(struct tm *d)
 	replace_date(d, tv);
 }
 
+static void set_tm_hour(struct tm *d)
+{
+        time_t t = time(NULL);
+        struct tm *tv = localtime(&t);
+        d->tm_sec = 0;          /* seconds */
+        d->tm_min = 0;          /* minutes */
+	replace_time(d, tv);
+}
+
 static int set_tm_boot(struct tm *d)
 {
 	char buf[128];
@@ -221,6 +240,8 @@ static void replace_date(struct tm *t1, struct tm *t2)
         t1->tm_mon = t2->tm_mon;	/* month */
         t1->tm_year = t2->tm_year;	/* year */
         t1->tm_isdst = t2->tm_isdst;	/* daylight savings time */
+	t1->tm_wday = t2->tm_wday;	/* Day of Week */
+	t1->tm_yday = t2->tm_yday;	/* Day of Year */
 }
 
 static int lookup_and_set_time(const char *da, struct tm *d)
@@ -235,6 +256,9 @@ static int lookup_and_set_time(const char *da, struct tm *d)
 			case T_RECENT:
 				set_tm_recent(d);
 				break;
+			case T_THIS_HOUR:
+				set_tm_hour(d);
+				break;
 			case T_BOOT:
 				if (set_tm_boot(d))
 					return -2;
@@ -263,13 +287,6 @@ static int lookup_and_set_time(const char *da, struct tm *d)
 		return -1;
 }
 
-/* static void print_time(struct tm *d)
-{
-	char outstr[200];
-	strftime(outstr, sizeof(outstr), "%c", d);
-	printf("%s\n", outstr);
-} */
-
 int ausearch_time_start(const char *da, const char *ti)
 {
 /* If da == NULL, use current date */
@@ -300,7 +317,7 @@ int ausearch_time_start(const char *da, const char *ti)
 		} else {
 			int keyword=lookup_time(da);
 			if (keyword == T_RECENT || keyword == T_NOW ||
-				keyword == T_BOOT) {
+				keyword == T_THIS_HOUR || keyword == T_BOOT) {
 				if (ti == NULL || strcmp(ti, "00:00:00") == 0)
 					goto set_it;
 			}
@@ -374,7 +391,7 @@ int ausearch_time_end(const char *da, const char *ti)
 		} else {
 			int keyword=lookup_time(da);
 			if (keyword == T_RECENT || keyword == T_NOW ||
-				keyword == T_BOOT) {
+				keyword == T_THIS_HOUR || keyword == T_BOOT) {
 				if (ti == NULL || strcmp(ti, "00:00:00") == 0)
 					goto set_it;
 			}
